@@ -1,9 +1,10 @@
-#' Are numerical column data between two specified values?
+#' Are column data between two specified values?
 #'
 #' The `col_vals_between()` validation step function checks whether column
 #' values (in any number of specified `columns`) fall within a range. The range
 #' specified with three arguments: `left`, `right`, and `inclusive`. The `left`
-#' and `right` values specify the lower and upper numeric bounds. The
+#' and `right` values specify the lower and upper bounds. The bounds can be
+#' specified as single, literal values or as column names given in `vars()`. The
 #' `inclusive` argument, as a vector of two logical values relating to `left`
 #' and `right`, states whether each bound is inclusive or not. The default is
 #' `c(TRUE, TRUE)`, where both endpoints are inclusive (i.e., `[left, right]`).
@@ -15,12 +16,12 @@
 #' the number of rows in the table (after any `preconditions` have been
 #' applied).
 #' 
-#' If providing multiple column names, the result will be an expansion of
-#' validation steps to that number of column names (e.g., `vars(col_a, col_b)`
-#' will result in the entry of two validation steps). Aside from column names
-#' in quotes and in `vars()`, **tidyselect** helper functions are available for
-#' specifying columns. They are: `starts_with()`, `ends_with()`, `contains()`,
-#' `matches()`, and `everything()`.
+#' If providing multiple column names to `columns`, the result will be an
+#' expansion of validation steps to that number of column names (e.g.,
+#' `vars(col_a, col_b)` will result in the entry of two validation steps). Aside
+#' from column names in quotes and in `vars()`, **tidyselect** helper functions
+#' are available for specifying columns. They are: `starts_with()`,
+#' `ends_with()`, `contains()`, `matches()`, and `everything()`.
 #' 
 #' This validation step function supports special handling of `NA` values. The
 #' `na_pass` argument will determine whether an `NA` value appearing in a test
@@ -61,9 +62,13 @@
 #'
 #' @inheritParams col_vals_gt
 #' @param left The lower bound for the range. The validation includes this bound
-#'   value in addition to values greater than `left`.
+#'   value (if the first element in `inclusive` is `TRUE`) in addition to values
+#'   greater than `left`. This can be a single value or a compatible column
+#'   given in `vars()`.
 #' @param right The upper bound for the range. The validation includes this
-#'   bound value in addition to values lower than `right`.
+#'   bound value (if the second element in `inclusive` is `TRUE`) in addition to
+#'   values lower than `right`. This can be a single value or a compatible
+#'   column given in `vars()`.
 #' @param inclusive A two-element logical value that indicates whether the
 #'   `left` and `right` bounds should be inclusive. By default, both bounds
 #'   are inclusive.
@@ -72,11 +77,10 @@
 #'   was passed to `x`.
 #'   
 #' @examples
-#' library(dplyr)
-#' 
 #' # Create a simple table with
 #' # a column of numerical values
-#' tbl <- tibble(a = c(5.6, 8.2, 7.8))
+#' tbl <- 
+#'   dplyr::tibble(a = c(5.6, 8.2, 7.8))
 #' 
 #' # Validate that values in
 #' # column `a` are all between
@@ -107,7 +111,8 @@ col_vals_between <- function(x,
                              na_pass = FALSE,
                              preconditions = NULL,
                              actions = NULL,
-                             brief = NULL) {
+                             brief = NULL,
+                             active = TRUE) {
   
   # Capture the `columns` expression
   columns <- rlang::enquo(columns)
@@ -120,7 +125,7 @@ col_vals_between <- function(x,
   
   if (is_a_table_object(x)) {
     
-    secret_agent <- create_agent(x) %>%
+    secret_agent <- create_agent(x, name = "::QUIET::") %>%
       col_vals_between(
         columns = columns,
         left = left,
@@ -129,7 +134,8 @@ col_vals_between <- function(x,
         na_pass = na_pass,
         preconditions = preconditions,
         brief = brief,
-        actions = prime_actions(actions)
+        actions = prime_actions(actions),
+        active = active
       ) %>% interrogate()
     
     return(x)
@@ -138,31 +144,24 @@ col_vals_between <- function(x,
   agent <- x
   
   if (is.null(brief)) {
-    
-    brief <-
-      create_autobrief(
-        agent = agent,
-        assertion_type = "col_vals_between",
-        column = columns,
-        left = left,
-        right = right
-      )
+    brief <- generate_autobriefs(agent, columns, preconditions, values = c(left, right), "col_vals_between")
   }
   
   # Add one or more validation steps based on the
   # length of the `columns` variable
-  for (column in columns) {
+  for (i in seq(columns)) {
     
     agent <-
       create_validation_step(
         agent = agent,
         assertion_type = "col_vals_between",
-        column = column,
-        set = c(left, right),
+        column = columns[i],
+        values = c(left, right),
         na_pass = na_pass,
         preconditions = preconditions,
         actions = actions,
-        brief = brief
+        brief = brief[i],
+        active = active
       )
   }
 
