@@ -1,28 +1,27 @@
-#' Are numerical column data not between two specified values?
-#'
-#' Verification step where column data should not be between two values.
+#' Are column data not between two specified values?
 #' 
 #' The `col_vals_not_between()` validation step function checks whether column
 #' values (in any number of specified `columns`) *do not* fall within a range.
 #' The range specified with three arguments: `left`, `right`, and `inclusive`.
-#' The `left` and `right` values specify the lower and upper numeric bounds. The
-#' `inclusive` argument, as a vector of two logical values relating to `left`
-#' and `right`, states whether each bound is inclusive or not. The default is
-#' `c(TRUE, TRUE)`, where both endpoints are inclusive (i.e., `[left, right]`).
-#' For partially-unbounded versions of this function, we can use the
-#' [col_vals_lt()], [col_vals_lte()], [col_vals_gt()], or [col_vals_gte()]
-#' validation step functions. This function can be used directly on a data table
-#' or with an *agent* object (technically, a `ptblank_agent` object). Each
-#' validation step will operate over the number of test units that is equal to
-#' the number of rows in the table (after any `preconditions` have been
-#' applied).
+#' The `left` and `right` values specify the lower and upper bounds. The bounds
+#' can be specified as single, literal values or as column names given in
+#' `vars()`. The `inclusive` argument, as a vector of two logical values
+#' relating to `left` and `right`, states whether each bound is inclusive or
+#' not. The default is `c(TRUE, TRUE)`, where both endpoints are inclusive
+#' (i.e., `[left, right]`). For partially-unbounded versions of this function,
+#' we can use the [col_vals_lt()], [col_vals_lte()], [col_vals_gt()], or
+#' [col_vals_gte()] validation step functions. This function can be used
+#' directly on a data table or with an *agent* object (technically, a
+#' `ptblank_agent` object). Each validation step will operate over the number of
+#' test units that is equal to the number of rows in the table (after any
+#' `preconditions` have been applied).
 #' 
-#' If providing multiple column names, the result will be an expansion of
-#' validation steps to that number of column names (e.g., `vars(col_a, col_b)`
-#' will result in the entry of two validation steps). Aside from column names
-#' in quotes and in `vars()`, **tidyselect** helper functions are available for
-#' specifying columns. They are: `starts_with()`, `ends_with()`, `contains()`,
-#' `matches()`, and `everything()`.
+#' If providing multiple column names to `columns`, the result will be an
+#' expansion of validation steps to that number of column names (e.g.,
+#' `vars(col_a, col_b)` will result in the entry of two validation steps). Aside
+#' from column names in quotes and in `vars()`, **tidyselect** helper functions
+#' are available for specifying columns. They are: `starts_with()`,
+#' `ends_with()`, `contains()`, `matches()`, and `everything()`.
 #' 
 #' This validation step function supports special handling of `NA` values. The
 #' `na_pass` argument will determine whether an `NA` value appearing in a test
@@ -70,11 +69,10 @@
 #'   was passed to `x`.
 #'   
 #' @examples
-#' library(dplyr)
-#' 
 #' # Create a simple table with a
 #' # column of numerical values
-#' tbl <- tibble(a = c(5.6, 7.8, 3.4))
+#' tbl <- 
+#'   dplyr::tibble(a = c(5.6, 7.8, 3.4))
 #' 
 #' # Validate that none of the values 
 #' # in column `a` are between 9 and 10,
@@ -106,7 +104,8 @@ col_vals_not_between <- function(x,
                                  na_pass = FALSE,
                                  preconditions = NULL,
                                  actions = NULL,
-                                 brief = NULL) {
+                                 brief = NULL,
+                                 active = TRUE) {
   
   # Capture the `columns` expression
   columns <- rlang::enquo(columns)
@@ -119,7 +118,7 @@ col_vals_not_between <- function(x,
   
   if (is_a_table_object(x)) {
     
-    secret_agent <- create_agent(x) %>%
+    secret_agent <- create_agent(x, name = "::QUIET::") %>%
       col_vals_not_between(
         columns = columns,
         left = left,
@@ -128,7 +127,8 @@ col_vals_not_between <- function(x,
         na_pass = na_pass,
         preconditions = preconditions,
         brief = brief,
-        actions = prime_actions(actions)
+        actions = prime_actions(actions),
+        active = active
       ) %>% interrogate()
     
     return(x)
@@ -137,31 +137,24 @@ col_vals_not_between <- function(x,
   agent <- x
   
   if (is.null(brief)) {
-    
-    brief <-
-      create_autobrief(
-        agent = agent,
-        assertion_type = "col_vals_not_between",
-        column = columns,
-        left = left,
-        right = right
-      )
+    brief <- generate_autobriefs(agent, columns, preconditions, values = c(left, right), "col_vals_not_between")
   }
   
   # Add one or more validation steps based on the
   # length of the `columns` variable
-  for (column in columns) {
+  for (i in seq(columns)) {
     
     agent <-
       create_validation_step(
         agent = agent,
         assertion_type = "col_vals_not_between",
-        column = column,
-        set = c(left, right),
+        column = columns[i],
+        values = c(left, right),
         na_pass = na_pass,
         preconditions = preconditions,
         actions = actions,
-        brief = brief
+        brief = brief[i],
+        active = active
       )
   }
 
