@@ -4,8 +4,59 @@ tbl <-
   small_table %>%
   dplyr::mutate(g = as.factor(f))
 
+schema_incorrect <- 
+  col_schema(
+    date_time = "POSIXct", date = "Date", 
+    a = "integer", b = "character", c = "numeric", d = "numeric", 
+    e = "logical", f = "character", g = "factor"
+  )
+
+schema_correct <- 
+  schema <- 
+  col_schema(
+    date_time = c("POSIXct", "POSIXt"), date = "Date", 
+    a = "integer", b = "character", c = "numeric", d = "numeric", 
+    e = "logical", f = "character", g = "factor"
+  )
+
 test_that("Interrogating simply returns the expected results", {
   
+  # Use the `col_schema_match()` function to perform
+  # a simple validation step
+  tbl_result <- tbl[1:2, ] %>% col_schema_match(schema = col_schema(.tbl = tbl))
+  
+  # Expect that `tbl_result` is equivalent to `tbl[1:2, ]`
+  expect_equivalent(tbl[1:2, ], tbl_result)
+  
+  # Use the `col_schema_match()` function to perform
+  # another simple validation step
+  tbl_result <- tbl[1:2, ] %>% col_schema_match(schema = schema_correct)
+  
+  # Expect that `tbl_result` is equivalent to `tbl[1:2, ]`
+  expect_equivalent(tbl[1:2, ], tbl_result)
+  
+  # Perform a simple validation that yields a warning
+  expect_warning(
+    tbl_result <- tbl %>% col_schema_match(schema = schema_incorrect)
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl`
+  expect_equivalent(tbl, tbl_result)
+  
+  rm(tbl_result)
+  
+  # Perform a simple validation step that results in stopping
+  expect_error(
+    tbl_result <- tbl %>% 
+      col_schema_match(
+        schema = schema_incorrect,
+        actions = action_levels(stop_at = 1)
+      )
+  )
+  
+  # Expect that `tbl_result` is never created
+  expect_false(exists("tbl_result"))
+  
   # Use the `rows_distinct()` function to perform
   # a simple validation step
   tbl_result <- tbl[1:2, ] %>% rows_distinct()
@@ -108,7 +159,7 @@ test_that("Interrogating simply returns the expected results", {
   
   # Use the `col_is_numeric()` function to perform
   # a simple validation step
-  tbl_result <- tbl %>% col_is_numeric(columns = vars(a))
+  suppressWarnings(tbl_result <- tbl %>% col_is_numeric(columns = vars(a)))
   
   # Expect that `tbl_result` is equivalent to `tbl`
   expect_equivalent(tbl, tbl_result)
@@ -363,9 +414,11 @@ test_that("Interrogating simply returns the expected results", {
   
   # Use the `col_vals_equal()` function to perform
   # a simple validation step
-  tbl_result <- 
-    tbl %>%
-    col_vals_equal(columns = vars(d), value = 283.94)
+  suppressWarnings(
+    tbl_result <- 
+      tbl %>%
+      col_vals_equal(columns = vars(d), value = 283.94)
+  )
   
   # Expect that `tbl_result` is equivalent to `tbl`
   expect_equivalent(tbl, tbl_result)
@@ -374,7 +427,16 @@ test_that("Interrogating simply returns the expected results", {
   expect_warning(
     tbl_result <- 
       tbl %>%
-      col_vals_equal(columns = vars(d), value = 283.94, actions = action_levels(warn_at = 1))
+      col_vals_equal(
+        columns = vars(d), value = 283.94,
+        actions = action_levels(warn_at = 1)
+      )
+  )
+  
+  expect_warning(
+    tbl_result <- 
+      tbl %>%
+      col_vals_equal(columns = vars(d), value = 283.94)
   )
   
   # Expect that `tbl_result` is equivalent to `tbl`
@@ -394,9 +456,11 @@ test_that("Interrogating simply returns the expected results", {
   
   # Use the `col_vals_not_equal()` function to perform
   # a simple validation step
-  tbl_result <- 
-    tbl %>%
-    col_vals_not_equal(columns = vars(d), value = 283.94)
+  suppressWarnings(
+    tbl_result <- 
+      tbl %>%
+      col_vals_not_equal(columns = vars(d), value = 283.94)
+  )
   
   # Expect that `tbl_result` is equivalent to `tbl`
   expect_equivalent(tbl, tbl_result)
@@ -622,12 +686,14 @@ test_that("Interrogating simply returns the expected results", {
   # Use the `conjointly()` function to perform
   # a conjoint validation validation step directly
   # on the `tbl` object
-  tbl_result <- 
-    tbl %>%
-    conjointly(
-      ~ col_vals_gt(., columns = vars(d), value = 200),
-      ~ col_vals_lt(., columns = vars(c), value = 10)
-    )
+  suppressWarnings(
+    tbl_result <- 
+      tbl %>%
+      conjointly(
+        ~ col_vals_gt(., columns = vars(d), value = 200),
+        ~ col_vals_lt(., columns = vars(c), value = 10)
+      )
+  )
     
   # Expect that `tbl_result` is equivalent to `tbl`
   expect_equivalent(tbl, tbl_result)
@@ -642,6 +708,14 @@ test_that("Interrogating simply returns the expected results", {
         actions = action_levels(warn_at = 1)
       )
   )
+  expect_warning(
+    tbl_result <- 
+      tbl %>%
+      conjointly(
+        ~ col_vals_gt(., columns = vars(d), value = 200),
+        ~ col_vals_lt(., columns = vars(c), value = 10)
+      )
+  )
   
   # Expect that `tbl_result` is equivalent to `tbl`
   expect_equivalent(tbl, tbl_result)
@@ -664,7 +738,41 @@ test_that("Interrogating simply returns the expected results", {
   
   # Using the `col_exists()` function to perform
   # a simple validation step results in a warning
-  expect_warning(tbl %>% col_exists(columns = vars(g)))
+  expect_warning(
+    tbl %>% col_exists(columns = vars(h), actions = action_levels(warn_at = 1))
+  )
+  expect_warning(
+    tbl %>% col_exists(columns = "h", actions = action_levels(warn_at = 1))
+  )
+  expect_warning(
+    tbl %>% col_exists(columns = vars(a, h), actions = action_levels(warn_at = 1))
+  )
+  expect_warning(
+    tbl %>% col_exists(columns = c("a", "h"), actions = action_levels(warn_at = 1))
+  )
+  
+  # Using the `col_exists()` function to perform
+  # a simple validation step results in an error
+  expect_error(
+    tbl %>% col_exists(columns = vars(h), actions = action_levels(stop_at = 1))
+  )
+  expect_error(
+    tbl %>% col_exists(columns = "h", actions = action_levels(stop_at = 1))
+  )
+  expect_error(
+    tbl %>% col_exists(columns = vars(a, h), actions = action_levels(stop_at = 1))
+  )
+  expect_error(
+    tbl %>% col_exists(columns = c("a", "h"), actions = action_levels(stop_at = 1))
+  )
+  
+  # Expect no warning or error if all column names are correct
+  expect_warning(regexp = NA,
+    tbl %>% col_exists(columns = colnames(tbl), actions = action_levels(warn_at = 1))
+  )
+  expect_error(regexp = NA,
+    tbl %>% col_exists(columns = colnames(tbl), actions = action_levels(stop_at = 1))
+  )
 })
 
 test_that("Interrogating simply incorporates the `na_pass` option", {
